# __init__.py
from .image import *
from .lotto import *
from .names import *
from .file import *

__all__ = [
    "show_image",
    "get_one_number",
    "get_human_name",
    "get_social_security_number",
    "get_school_name",
    "get_country_name",
    "get_robot_name",
    "get_vehicle_company",
    "get_color_name",
    "get_colors",
    "get_one_set",
    "get_one_set_sorted",
    "get_one_set_string",
    "get_one_set_string_bracket",
    "get_some_sets",
    "get_file_name",
    "get_text"
]

# __all__ = image.__all__ + lotto.__all__ + names.__all__

__version__ = '0.0.14'


import random

def get_filename(ext="txt"):
    # 200개의 새 이름 목록 정의
    bird_names = [
        "albatross", "avocet", "blackbird", "bluejay", "canary", "cardinal", "chickadee", "crane",
        "cuckoo", "dove", "duck", "eagle", "egret", "falcon", "flamingo", "finch", "goldfinch",
        "goose", "gull", "hawk", "heron", "hummingbird", "ibis", "jay", "kingfisher", "kiwi",
        "kookaburra", "lapwing", "lark", "loon", "magpie", "mallard", "mockingbird", "nightingale",
        "nuthatch", "osprey", "ostrich", "owl", "parrot", "partridge", "peacock", "pelican", "penguin",
        "pheasant", "pigeon", "plover", "ptarmigan", "puffin", "quail", "raven", "redpoll", "robin",
        "rook", "sandpiper", "seagull", "sparrow", "stork", "swallow", "swift", "tern", "thrush",
        "toucan", "vulture", "warbler", "waxwing", "woodpecker", "wren", "bunting", "buzzard", 
        "cormorant", "curlew", "dotterel", "dowitcher", "flicker", "godwit", "goldeneye", "goshawk", 
        "grebe", "grosbeak", "harrier", "hoopoe", "hornbill", "hornedlark", "ibisbill", "jacamar", 
        "jacana", "jackdaw", "junglefowl", "kestrel", "kite", "lapwing", "leafbird", "linnet", 
        "manakin", "meadowlark", "merganser", "murre", "noddynot", "nuthatch", "oriole", "oxpecker", 
        "parula", "petrel", "phoebe", "potoo", "puffleg", "quailfinch", "quailthrush", "quelea", 
        "quetzal", "rail", "redstart", "reeve", "rhea", "rosefinch", "ross'goose", "rufous", "sandgrouse", 
        "scoter", "serin", "shearwater", "shrike", "skua", "skylark", "snipe", "solitaire", "spoonbill", 
        "starling", "stilts", "stonechat", "stork", "stint", "stormpetrel", "sunbird", "swiftlet", 
        "tanager", "tattler", "teal", "tern", "thickknee", "thornbill", "thrush", "titmouse", 
        "toucanet", "towhee", "treepie", "triller", "trogan", "turaco", "turnstone", "verdin", 
        "vireo", "vulture", "wagtail", "weaver", "whimbrel", "whippoorwill", "whistlingduck", 
        "woodcock", "wren", "yellowlegs", "yellowthroat", "zittingcisticola"
    ]
    
    # 새 이름 목록에서 랜덤하게 하나 선택
    random_name = random.choice(bird_names)
    
    # 파일 이름에 확장자를 붙여서 반환
    filename = f"{random_name}.{ext}"
    
    return filename

import random

def get_text():
    # 영어 격언 문장 20개
    english_quotes = [
        "The early bird catches the worm.",
        "A stitch in time saves nine.",
        "Actions speak louder than words.",
        "A journey of a thousand miles begins with a single step.",
        "Don't judge a book by its cover.",
        "Better late than never.",
        "Birds of a feather flock together.",
        "A picture is worth a thousand words.",
        "Every cloud has a silver lining.",
        "Fortune favors the bold.",
        "Honesty is the best policy.",
        "Hope for the best, but prepare for the worst.",
        "If it ain't broke, don't fix it.",
        "Practice makes perfect.",
        "Rome wasn't built in a day.",
        "The pen is mightier than the sword.",
        "When in Rome, do as the Romans do.",
        "Where there's smoke, there's fire.",
        "You can lead a horse to water, but you can't make it drink.",
        "You can't judge a book by its cover."
    ]
    
    # 한글 격언 문장 20개
    korean_quotes = [
        "가는 말이 고와야 오는 말이 곱다.",
        "개천에서 용 난다.",
        "구슬이 서 말이라도 꿰어야 보배다.",
        "금강산도 식후경.",
        "낮말은 새가 듣고 밤말은 쥐가 듣는다.",
        "누워서 떡 먹기.",
        "등잔 밑이 어둡다.",
        "말 한마디로 천 냥 빚 갚는다.",
        "백지장도 맞들면 낫다.",
        "서당 개 삼 년에 풍월을 읊는다.",
        "세 살 버릇 여든까지 간다.",
        "수박 겉 핥기.",
        "아는 것이 힘이다.",
        "없는 자식 귀여운 줄 모른다.",
        "열 번 찍어 안 넘어가는 나무 없다.",
        "오르지 못할 나무는 쳐다보지도 마라.",
        "원숭이도 나무에서 떨어진다.",
        "천 리 길도 한 걸음부터.",
        "하늘이 무너져도 솟아날 구멍이 있다.",
        "호랑이도 제 말 하면 온다."
    ]
    
    # 영어 격언과 한글 격언을 합친 리스트
    all_quotes = english_quotes + korean_quotes
    
    # 리스트에서 랜덤하게 하나 선택하여 반환
    return random.choice(all_quotes)



from faker import Faker
import random 
import re 

fake = Faker()
#  ko_kr로 세팅
fake = Faker('ko_KR') 

schools = [
    '강동초등학교', '강명초등학교', '강솔초등학교', '고덕초등학교', '길동초등학교', 
    '둔촌초등학교', '명일초등학교', '상일초등학교', '성내초등학교', '암사초등학교'
]

countries = [
    '대한민국', '미국', '일본', '중국', '러시아', '독일', '프랑스', '영국', '이탈리아', '스페인',
    '캐나다', '멕시코', '브라질', '아르헨티나', '칠레', '콜롬비아', '페루', '베네수엘라', '호주', '뉴질랜드',
    '인도', '파키스탄', '방글라데시', '네팔', '스리랑카', '미얀마', '태국', '베트남', '말레이시아', '싱가포르',
    '인도네시아', '필리핀', '사우디아라비아', '이란', '이라크', '이스라엘', '터키', '이집트', '남아프리카공화국', '나이지리아',
    '케냐', '에티오피아', '탄자니아', '우간다', '가나', '코트디부아르', '모로코', '알제리', '튀니지', '리비아',
    '그리스', '포르투갈', '네덜란드', '벨기에', '스웨덴', '노르웨이', '덴마크', '핀란드', '폴란드', '체코',
    '헝가리', '오스트리아', '스위스', '루마니아', '불가리아', '크로아티아', '세르비아', '슬로바키아', '슬로베니아', '우크라이나'
]

robots = ['EV3', 'Spike Prime', 'Atobot', '로봇태권V', '마징가', 'R2D2', 'C3PO', 'Data', 'Bender', 'Hal', 'Optimus Prime', 'Wall-E', 'Eve', 'Johnny 5', 'K-9', 'T-800', 'BB-8', 'Robby', 'Gort', 'Maria']
vehicles = ['현대', '기아', '토요타', '벤츠', 'BMW', '아우디', '폭스바겐', '포드', '쉐보레', '닛산', '혼다', '마쯔다', '스바루', '테슬라', '볼보', '푸조', '시트로엥', '르노', '피아트', '람보르기니']
colors = [
    '빨강', '주황', '노랑', '초록', '파랑', '남색', '보라', '분홍', '갈색', '회색', 
    '검정', '흰색', '연두색', '하늘색', '자주색', '연분홍색', '연노랑색', '연파랑색', '연보라색', '연갈색', 
    '연회색', '진빨강', '진주황', '진노랑', '진초록', '진파랑', '진남색', '진보라', '진분홍', '진갈색', 
    '진회색', '진검정'
]

def get_human_name():
    return fake.name()

def get_social_security_number():
    return fake.ssn()

def get_school_name():
    return fake.random_element(schools)

def get_country_name():
    return fake.random_element(countries)

def get_robot_name():
    return fake.random_element(robots)

def get_vehicle_company():
    return fake.random_element(vehicles)

def get_color_name():
    return fake.random_element(colors)

def get_colors():
    return fake.random_elements(elements=colors, length=5, unique=True)

def get_image_url():
    # return fake.image_url()
    base_urls = ['https://codingschoool.co.kr/img/', 'https://learnsteam.co.kr/img/', 'https://codingeverybody.com/abc/img/', 'https://codingeverybody.com/def/kor/img/']
    files = fake.file_name(category='image')

    return f"{fake.random_element(base_urls)}{files}"



import random

def get_one_number():
    return random.randint(1, 45)

def get_one_set():
    numbers = set()
    while len(numbers) < 6:
        numbers.add(random.randint(1, 45))
    return list(numbers)

def get_one_set_sorted():
    numbers = get_one_set()
    numbers.sort()
    return numbers

def get_one_set_string():
    numbers = get_one_set_sorted()
    return ', '.join(str(n) for n in numbers)

def get_one_set_string_bracket():
    numbers = get_one_set_sorted()
    return '[' + ', '.join(str(n) for n in numbers) + ']'

def get_some_sets(count=5):
    return [get_one_set() for _ in range(count)]


from setuptools import setup, find_packages
import os

this_directory = os.path.abspath(os.path.dirname(__file__))
readme =  os.path.join(this_directory, "README.md")  #(this_directory / "README.md").read_text()
with open(readme, encoding='utf-8') as f:
    long_description = f.read()

setup(
    name="atolibrary",
    version="0.0.14",
    author="ATO JEON",
    author_email="atto.jeon@gmail.com",
    description="A utility library for image processing and random number generation",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/attojeon/atolibrary",  # GitHub 저장소 URL을 여기에 넣으세요
    packages=find_packages(),
    install_requires=[
        'Pillow>=9.0.0',
        'requests',
        'faker',
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)